# DRC/LVS with Pegasus

## Pegasus usage notes

 Although batch Pegasus is primarily command-line option driven, the only way to override certain directives in the rule decks is to generate a control file called `pegasusdrcctl` for DRC or `pegasuslvsctl` for LVS.
* This file can also be used to fill in fields in the GUI version for debugging, and changes in the the GUI will then overwrite this file.
* This file is generated by the `generate_drc_ctl_file`/`generate_lvs_ctl_file` step. Changes to what appears in this file must be done with either the key `drc.inputs.additional_drc_text`/`lvs.inputs.additional_lvs_text` with each line terminated by a semicolon (appends to the end of the generated file), or with a replacement hook.

## Pegasus Design Review usage notes

Pegasus Design Review (DR) and Results Viewer (RV) together are the GUI DRC/LVS results browser.

The first time you open DR with the `view_drc`/`view_lvs` script, you will get an error message:

A Valid Technology File Path is Required?
"": Not Found?

This is because you need to load the DRC/LVS deck as a technology.

To import the technology, in the main Design Review windows, go to:

Tools -> Technology Manager (window pops up) -> File -> Import -> PVL (tab)

In this dialog window, enter the technology basename in the Hammer input key `vlsi.core.technology` (e.g. "sky130", not "hammer.technology.sky130") in the "Technology Name" field and browse to the DRC/LVS deck in the PVL Rule File dialog. Then hit Import, close the Technology Manager, close DR, and run the `view_drc`/`view_lvs` script again.

Subsequent openings of databases anywhere will map to this technology and label layers properly because the technology information is stored your home directory.

Tested with:

* sky130
